@@ -154,6 +154,6 @@ plotFan<-function(tree,colors,fsize,ftype,lwd,mar,add){
 		adj<-if(aa>90&&aa<270) c(1,0.25) else c(0,0.25)
 		tt<-if(aa>90&&aa<270) paste(cw$tip.label[i]," ",sep="") else paste(" ",cw$tip.label[i],sep="")
 		aa<-if(aa>90&&aa<270) 180+aa else aa
-		text(x[ii,2],y[ii,2],tt,srt=aa,adj=adj,cex=fsize,font=ftype)
+		if(ftype) text(x[ii,2],y[ii,2],tt,srt=aa,adj=adj,cex=fsize,font=ftype)
 	}
 }
