@@ -20,18 +20,18 @@ plotTree<-function(tree,...){
 	else add<-FALSE
 	if(hasArg(offset)) offset<-list(...)$offset
 	else offset<-NULL
-	# if(hasArg(shift)) shift<-list(...)$shift
-	# else shift<-NULL
+	if(hasArg(type)) type<-list(...)$type
+	else type<-"phylogram"
 	if(hasArg(direction)) direction<-list(...)$direction
 	else direction<-"rightwards"
 	if(class(tree)=="multiPhylo"){
 		par(ask=TRUE)
 		if(!is.null(color)) names(color)<-"1"
-		for(i in 1:length(tree)) plotTree(tree[[i]],color=color,fsize=fsize,ftype=ftype,lwd=lwd,pts=pts,node.numbers=node.numbers,mar=mar,add=add,offset=offset,direction=direction)
+		for(i in 1:length(tree)) plotTree(tree[[i]],color=color,fsize=fsize,ftype=ftype,lwd=lwd,pts=pts,node.numbers=node.numbers,mar=mar,add=add,offset=offset,direction=direction,type=type)
 	} else {
 		tree$maps<-as.list(tree$edge.length)
 		for(i in 1:length(tree$maps)) names(tree$maps[[i]])<-c("1")
 		if(!is.null(color)) names(color)<-"1"
-		plotSimmap(tree,colors=color,fsize=fsize,ftype=ftype,lwd=lwd,pts=pts,node.numbers=node.numbers,mar=mar,add=add,offset=offset,direction=direction)
+		plotSimmap(tree,colors=color,fsize=fsize,ftype=ftype,lwd=lwd,pts=pts,node.numbers=node.numbers,mar=mar,add=add,offset=offset,direction=direction,type=type)
 	}
 }
